@@ -127,6 +127,7 @@ class User(UserCompact):
     title_url: Optional[str]
     twitter: Optional[str]
     website: Optional[str]
+    scores_pinned_count: int
 
     def expand(self) -> User:
         # we're already expanded, no need to waste an api call
@@ -217,6 +218,7 @@ class BeatmapsetCompact(Model):
     user_id: int
     video: bool
     nsfw: bool
+    offset: int
     # documented as being in ``Beatmapset`` only, but returned by
     # ``api.beatmapset_events`` which uses a ``BeatmapsetCompact``.
     hype: Optional[Hype]
@@ -289,6 +291,7 @@ class Score(Model):
     mode_int: int
     replay: bool
     passed: bool
+    current_user_attributes: Any
 
     beatmap: Optional[Beatmap]
     beatmapset: Optional[BeatmapsetCompact]
@@ -421,6 +424,7 @@ class ForumTopic(Model):
     type: ForumTopicType
     updated_at: Datetime
     user_id: int
+    poll: Any
 
     def user(self) -> User:
         return self._fk_user(self.user_id)
@@ -430,6 +434,7 @@ class ForumTopicAndPosts(Model):
     search: ForumTopicSearch
     posts: List[ForumPost]
     topic: ForumTopic
+    cursor_string: Optional[str]
 
 class ForumTopicSearch(Model):
     sort: Optional[ForumTopicSort]
@@ -543,6 +548,7 @@ class BeatmapsetDiscussionVote(Model):
     beatmapset_discussion_id: int
     created_at: Datetime
     updated_at: Datetime
+    cursor_string: Optional[str]
 
     def user(self):
         return self._fk_user(self.user_id)
@@ -775,6 +781,7 @@ class BeatmapsetSearchResult(Model):
     error: Optional[str]
     total: int
     search: Any
+    cursor_string: Optional[str]
 
 class BeatmapsetDiscussions(Model):
     beatmaps: List[Beatmap]
@@ -783,6 +790,7 @@ class BeatmapsetDiscussions(Model):
     included_discussions: List[BeatmapsetDiscussion]
     reviews_config: ReviewsConfig
     users: List[UserCompact]
+    cursor_string: Optional[str]
 
 class BeatmapsetDiscussionReview(Model):
     # https://github.com/ppy/osu-web/blob/master/app/Libraries/BeatmapsetDiscussionReview.php
@@ -794,12 +802,14 @@ class BeatmapsetDiscussionPosts(Model):
     cursor: CursorT
     posts: List[BeatmapsetDiscussionPost]
     users: List[UserCompact]
+    cursor_string: Optional[str]
 
 class BeatmapsetDiscussionVotes(Model):
     cursor: CursorT
     discussions: List[BeatmapsetDiscussion]
     votes: List[BeatmapsetDiscussionVote]
     users: List[UserCompact]
+    cursor_string: Optional[str]
 
 class BeatmapsetEventComment(Model):
     beatmap_discussion_id: int
